@@ -1,6 +1,6 @@
 /*
- * gnome-canvas-component.c: implements the CORBA interface for
- * the GNOME::Canvas:Item interface used in Bonobo::Views.
+ * bonobo-canvas-component.c: implements the CORBA interface for
+ * the Bonobo::Canvas:Item interface used in Bonobo::Views.
  *
  * Author:
  *   Miguel de Icaza (miguel@kernel.org)
@@ -228,7 +228,7 @@ gcc_realize (PortableServer_Servant servant,
 	GdkWindow *gdk_window = gdk_window_foreign_new (window);
 
 	if (gdk_window == NULL){
-		g_warning ("Invalid window id passed=0x%x\n", window);
+		g_warning ("Invalid window id passed=0x%x", window);
 		return;
 	}
 
@@ -303,7 +303,7 @@ gcc_draw (PortableServer_Servant servant,
 	pix = gdk_pixmap_foreign_new (drawable);
 
 	if (pix == NULL){
-		g_warning ("Invalid window id passed=0x%x\n", drawable);
+		g_warning ("Invalid window id passed=0x%x", drawable);
 		return;
 	}
 
@@ -673,7 +673,7 @@ bonobo_canvas_component_object_create (BonoboObject *object)
  * @corba_canvas_comp: A Bonobo_Canvas_Component corba object.
  * @item: A #GnomeCanvasItem that is being exported
  *
- * Creates a CORBA server for the interface GNOME::Canvas::Item
+ * Creates a CORBA server for the interface Bonobo::Canvas::Item
  * wrapping @item.
  *
  * Returns: The BonoboCanvasComponent.
@@ -700,7 +700,7 @@ bonobo_canvas_component_construct (BonoboCanvasComponent *comp,
  * bonobo_canvas_component_new:
  * @item: A GnomeCanvasItem that is being exported
  *
- * Creates a CORBA server for the interface GNOME::Canvas::Item
+ * Creates a CORBA server for the interface Bonobo::Canvas::Item
  * wrapping @item.
  *
  * Returns: The BonoboCanvasComponent.
