@@ -10,14 +10,22 @@
 
 #include <config.h>
 #include <gnome.h>
-#include <bonobo.h>
+
+#if USING_OAF
+#include <liboaf/liboaf.h>
+#else
 #include <libgnorba/gnorba.h>
+#endif
+
+#include <bonobo.h>
+#include <bonobo/bonobo-print.h>
+#include <libgnomeprint/gnome-print.h>
 
 /*
  * Number of running objects
  */ 
 static int running_objects = 0;
-static BonoboEmbeddableFactory *factory = NULL;
+static BonoboGenericFactory *factory = NULL;
 
 /*
  * The Embeddable data.
@@ -541,16 +549,52 @@ view_factory (BonoboEmbeddable       *embeddable,
 	return view;
 }
 
+static void
+render_fn (GnomePrintContext         *ctx,
+	   double                     width,
+	   double                     height,
+	   const Bonobo_PrintScissor *scissor,
+	   gpointer                   user_data)
+{
+	GnomeFont         *font;
+	double             w;
+	const char         str [] = "Hello World";
+
+	gnome_print_setlinewidth (ctx, 2);
+	font = gnome_font_new ("Helvetica", 12.0);
+	g_return_if_fail (font != NULL);
+	gnome_print_setrgbcolor (ctx, 0.0, 0.0, 0.0);
+	gnome_print_setfont (ctx, font);
+
+	w = gnome_font_get_width_string (font, str);
+	gnome_print_moveto (ctx, (width / 2) - (w / 2),
+			    height / 2);
+	gnome_print_show (ctx, str);
+	gtk_object_unref (GTK_OBJECT (font));
+
+	gnome_print_moveto (ctx, 0, 0);
+	gnome_print_lineto (ctx, width, height);
+	gnome_print_stroke (ctx);
+
+/* We need a sensible internal representation in order to find the rowstride etc. */
+/*	gnome_print_rgbimage (ctx, embeddable_data->
+						  embeddable_data->width,
+						  embeddable_data->height,
+						  gdk_visual_get_best_depth ());*/
+}
+
+
 /*
- * When a container asks our EmbeddableFactory for a new paint
+ * When a container asks our GenericFactory for a new paint
  * component, this function is called.  It creates the new
  * BonoboEmbeddable object and returns it.
  */
 static BonoboObject *
-embeddable_factory (BonoboEmbeddableFactory *this,
+embeddable_factory (BonoboGenericFactory *this,
 		    void *data)
 {
 	BonoboEmbeddable *embeddable;
+	BonoboObject     *print;
 	embeddable_data_t *embeddable_data;
 
 	/*
@@ -590,6 +634,13 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 	embeddable = bonobo_embeddable_new (BONOBO_VIEW_FACTORY (view_factory),
 					    embeddable_data);
 
+	print = BONOBO_OBJECT (bonobo_print_new (render_fn, embeddable_data));
+	if (!print)
+		g_warning ("Serious error creating print interface");
+	else
+		bonobo_object_add_interface (BONOBO_OBJECT (embeddable),
+					     BONOBO_OBJECT (print));
+
 	if (embeddable == NULL) {
 		g_free (embeddable_data);
 		return NULL;
@@ -644,7 +695,7 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 	return BONOBO_OBJECT (embeddable);
 }
 
-static BonoboEmbeddableFactory *
+static BonoboGenericFactory *
 init_simple_paint_factory (void)
 {
 	/*
@@ -653,9 +704,15 @@ init_simple_paint_factory (void)
 	 * component, it will ask the factory to create one, and the
 	 * factory will invoke our embeddable_factory() function.
 	 */
-	return bonobo_embeddable_factory_new (
-		"embeddable-factory:paint-component-simple",
-		embeddable_factory, NULL);
+#if USING_OAF
+         return bonobo_generic_factory_new (
+			    "OAFIID:paint_component_simple_factory:301d4c2f-3f2b-404d-99e5-3fde72a1e601",
+			     embeddable_factory, NULL);
+#else
+         return bonobo_generic_factory_new (
+			     "embeddable-factory:paint-component-simple",
+			     embeddable_factory, NULL);  
+#endif
 }
 
 static void
@@ -666,13 +723,21 @@ init_server_factory (int argc, char **argv)
 
 	CORBA_exception_init (&ev);
 
+#if USING_OAF
+        gnome_init_with_popt_table("bonobo-simple-paint", VERSION,
+				   argc, argv,
+				   oaf_popt_options, 0, NULL); 
+	orb = oaf_init (argc, argv);
+#else
 	gnome_CORBA_init_with_popt_table (
 		"bonobo-simple-paint", VERSION,
 		&argc, argv, NULL, 0, NULL, GNORBA_INIT_SERVER_FUNC, &ev);
 
 	CORBA_exception_free (&ev);
-
 	orb = gnome_CORBA_ORB ();
+#endif
+
+
 	if (bonobo_init (orb, NULL, NULL) == FALSE)
 		g_error (_("Could not initialize Bonobo!"));
 }
